[Secure-testing-commits] r11217 - lib/python

thijs at alioth.debian.org thijs at alioth.debian.org
Sat Feb 14 17:11:04 UTC 2009


Author: thijs
Date: 2009-02-14 17:11:04 +0000 (Sat, 14 Feb 2009)
New Revision: 11217

Modified:
   lib/python/debian_support.py
   lib/python/dist_config.py
   lib/python/security_db.py
Log:
more occurences of etch,lenny,squeeze


Modified: lib/python/debian_support.py
===================================================================
--- lib/python/debian_support.py	2009-02-14 17:02:12 UTC (rev 11216)
+++ lib/python/debian_support.py	2009-02-14 17:11:04 UTC (rev 11217)
@@ -172,7 +172,7 @@
 
 def listReleases():
     releases = {}
-    rels = ("potato", "woody", "sarge", "etch", "lenny", "sid")
+    rels = ("potato", "woody", "sarge", "etch", "lenny", "squeeze", "sid")
     for r in range(len(rels)):
         releases[rels[r]] = Release(rels[r], r)
     Release.releases = releases

Modified: lib/python/dist_config.py
===================================================================
--- lib/python/dist_config.py	2009-02-14 17:02:12 UTC (rev 11216)
+++ lib/python/dist_config.py	2009-02-14 17:11:04 UTC (rev 11217)
@@ -47,6 +47,10 @@
     add_release(name='lenny',
                 architectures=lenny_archs,
                 )
+    
+    add_release(name='squeeze',
+                architectures=lenny_archs,
+                )
 
     add_release(name='sid',
                 architectures=lenny_archs,

Modified: lib/python/security_db.py
===================================================================
--- lib/python/security_db.py	2009-02-14 17:02:12 UTC (rev 11216)
+++ lib/python/security_db.py	2009-02-14 17:11:04 UTC (rev 11217)
@@ -372,7 +372,7 @@
             COALESCE((SELECT NOT vulnerable
             FROM source_packages AS tsecp, source_package_status AS tsecst
             WHERE tsecp.name = sp.name
-            AND tsecp.release = 'lenny' AND tsecp.subrelease = 'security'
+            AND tsecp.release = 'squeeze' AND tsecp.subrelease = 'security'
             AND tsecp.archive = sp.archive
             AND tsecst.bug_name = st.bug_name
             AND tsecst.package = tsecp.rowid), 0) AS testing_security_fixed,
@@ -381,14 +381,14 @@
             (EXISTS (SELECT * FROM package_notes_nodsa AS pnd
             WHERE pnd.bug_name = st.bug_name
             AND pnd.package = sp.name
-            AND pnd.release = 'lenny')) AS no_dsa
+            AND pnd.release = 'squeeze')) AS no_dsa
             FROM source_package_status AS st, source_packages AS sp
             WHERE st.vulnerable AND st.urgency <> 'unimportant'
-            AND sp.rowid = st.package AND sp.release = 'lenny'
+            AND sp.rowid = st.package AND sp.release = 'squeeze'
             AND sp.subrelease = ''
             ORDER BY sp.name, st.urgency, st.bug_name""")
 
-        for (name, nickname) in (('stable', 'etch'),):
+        for (name, nickname) in (('stable', 'lenny'),):
             cursor.execute(
                 """CREATE VIEW %s_status AS
                 SELECT DISTINCT sp.name AS package, st.bug_name AS bug,
@@ -447,7 +447,7 @@
                 return 999
         self.db.createscalarfunction("urgency_to_number", urgency_to_number, 1)
 
-        releases = ['potato', 'woody', 'sarge', 'etch', 'lenny', 'sid']
+        releases = ['potato', 'woody', 'sarge', 'etch', 'lenny', 'squeeze', 'sid']
         def release_to_number(u):
             try:
                 return releases.index(u)
@@ -951,7 +951,7 @@
         """Calculate vulnerable packages.
 
         To each package note, a release-specific vulnerability status
         is attached.  Currently, only lenny/testing is processed.
 
         Returns a list strings describing inconsistencies.
         """
@@ -967,7 +967,7 @@
         # The following does not work because stable->security ->
         # testing -> unstable propagation is no longer available.
         if False:
             # Ignore lenny/testing because stable issues may be
             # fast-tracked into testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
                     in list(cursor.execute(
@@ -975,7 +975,7 @@
             a.fixed_version, b.fixed_version
             FROM package_notes a, package_notes b
             WHERE a.bug_name = b.bug_name AND a.package = b.package
-            AND a.release = '' AND b.release NOT IN ('', 'lenny')
+            AND a.release = '' AND b.release NOT IN ('', 'squeeze')
             AND a.fixed_version IS NOT NULL
             AND a.fixed_version_id < b.fixed_version_id""")):
                 b = bugs.BugFromDB(cursor, bug_name)
@@ -1128,8 +1128,9 @@
             "SELECT name FROM bugs WHERE NOT not_for_us"):
 
             self._calcUnstable(c, bug_name)
-            self._calcTesting(c, bug_name, 'testing', 'lenny')
-            self._calcTesting(c, bug_name, 'stable', 'etch')
+            self._calcTesting(c, bug_name, 'testing', 'squeeze')
+            self._calcTesting(c, bug_name, 'stable', 'lenny')
+            self._calcTesting(c, bug_name, 'oldstable', 'etch')
 
         return result
 
@@ -1553,7 +1554,7 @@
 
             store_value('release/1/' + release, '\n'.join(result))
 
-        for release in ('sid', 'etch', 'lenny'):
+        for release in ('sid', 'etch', 'lenny', 'squeeze'):
             gen_release(release)
 
         result = result_start
@@ -1566,7 +1567,7 @@
                 
     def calculateDebsecan(self):
         """Calculate all debsecan data."""
-        for release in ('', 'etch', 'lenny'):
+        for release in ('', 'etch', 'lenny', 'squeeze'):
             self.calculateDebsecan0(release)
         self.calculateDebsecan1()
         
@@ -951,7 +951,7 @@
 
         To each package note, a release-specific vulnerability status
-        is attached.  Currently, only lenny/testing is processed.
+        is attached.  Currently, only squeeze/testing is processed.
 
         Returns a list strings describing inconsistencies.
@@ -967,7 +967,7 @@
         # testing -> unstable propagation is no longer available.
         if False:
-            # Ignore lenny/testing because stable issues may be
+            # Ignore squeeze/testing because stable issues may be
             # fast-tracked into testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \




More information about the Secure-testing-commits mailing list